Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterDecoder ¶
func RegisterDecoder(contentType string, decoder func(io.ReadCloser) Decoder)
Types ¶
type Decoder ¶
func NewDecoder ¶
type Stream ¶
type Stream[T any] struct { // contains filtered or unexported fields }
type StreamError ¶
StreamError represents an error event that occurred during streaming, preserving the original event data for structured access.
func (*StreamError) Error ¶
func (e *StreamError) Error() string
Click to show internal directories.
Click to hide internal directories.